import numpy as np
import hwm93fort
from datetime import datetime
from sciencedates import datetime2gtd
from dateutil.parser import parse
import xarray


def run(time: datetime, altkm: np.ndarray, glat: float, glon: float,
        f107a: float, f107: float, ap: int) -> xarray.Dataset:
    altkm = np.atleast_1d(altkm).astype(float)

    if isinstance(time, str):
        time = parse(time)

    iyd, utsec, stl = datetime2gtd(time, glon)

    merid = np.empty(altkm.size, dtype=float)
    zonal = np.empty(altkm.size, dtype=float)

    for i, a in enumerate(altkm):
        w = hwm93fort.gws5(iyd, utsec, a, glat, glon, stl, f107a, f107, (ap, ap))
        merid[i] = w[0]
        zonal[i] = w[1]

# %% assemble output
    winds = xarray.Dataset({'meridional': ('alt_km', merid),
                            'zonal': ('alt_km', zonal)},
                           coords={'alt_km': altkm},
                           attrs={'time': time.isoformat(), 'glat': glat, 'glon': glon})

    return winds



#!/usr/bin/env python
import setuptools  # noqa: F401
from numpy.distutils.core import setup, Extension

ext = Extension(name='hwm93fort',
                sources=['src/hwm93_sub.f'],
                f2py_options=['only:', 'gws5', ':'])

setup(ext_modules=[ext])



from matplotlib.pyplot import figure
import xarray


def plothwm(winds: xarray.Dataset):

    ax = figure().gca()
    ax.plot(winds['meridional'], winds.alt_km, label='meridional')
    ax.plot(winds['zonal'], winds.alt_km, label='zonal')
    ax.set_ylabel('altitude [km]')
    ax.set_xlabel('winds [m/s]')
    ax.legend(loc='best')
    ax.grid(True)
    ax.set_title(f'HWM93 Meridional / Zonal winds,\n '
                 f'{winds.time} lat/lon={winds.glat:.1f}, {winds.glon:.1f}')
